@@ -15,11 +15,6 @@
 int usb_debug = 0;
 struct usb_bus *usb_busses = NULL;
 
-int usb_find_devices_on_bus(struct usb_bus *bus);
-int usb_os_open(usb_dev_handle *dev);
-int usb_os_close(usb_dev_handle *dev);
-void usb_os_init(void);
-
 int usb_find_devices(void)
 {
   struct usb_bus *bus;
@@ -59,6 +54,7 @@ usb_dev_handle *usb_open(struct usb_device *dev)
   if (!udev)
     return NULL;
 
+  udev->fd = -1;
   udev->device = dev;
   udev->bus = dev->bus;
   udev->config = udev->interface = udev->altsetting = -1;
